; Screen Dimension Test by Chris Covell
; This tests out the screen positioning regs of the VDC.

        .include "startup.asm"
	.nomlist
	.list
; ----
; defines

FILE_CURS_LINE	.equ 10		;This might change!

; Zero-page variables

	.zp

__sp
__stack    .ds 2
__arg_idx  .ds 1
__temp     .ds 8
__ptr      .ds 2
__fbank    .ds 1
__fptr     .ds 2
__expr     .ds 2
_bp	   .ds 4


nmi_count: 	ds 1	;Counter for NMIs...
nmi_passed:	ds 1
a_cnt:		ds 1
VCE_copy:	ds 1
x_scroll:	ds 2
y_scroll:	ds 2
line_number:	ds 1	;Line position down the screen...
row_number:	ds 2	;"Row" position across the screen...
entry_total:	ds 1	;Total # of entries 0,1..x
entry_number:	ds 1	;File selected, starting at 1.
;----------- BCD Routine Variables! ----------
bcd_out0:	.ds 1	;Highest byte
bcd_out1:	.ds 1
bcd_out2:	.ds 1	;Lowest bytes
bcd_inp0:	.ds 1	;LSB
bcd_inp1:	.ds 1	;MSB
;------------------------

dummy_tii:	ds 1
file_source:	ds 2	;Source of selected file.
file_dest:	ds 2	;Destination of file...
file_size:	ds 2	;Storage for size of selected file.
dummy_rts:	ds 1	;Dummy for TII instruction.
edit_ptr:	ds 2	;Pointer into file for editing.
edit_nyb:	ds 1	;Which nybble?
old_ed_ptr:	ds 2
old_asc_ptr:	ds 2
sx		ds 2	;Sprite X coord
sy		ds 2	;Sprite Y coord

menu_moved:	ds 1	;
menu_opt:	ds 1	;Edit, Backup, Restore, Delete
menu_status:	ds 1	;0=NONE, 1=menu, 2=name select,
			;3=editing, 4=confirmation
cursor_opt:	ds 1	;Cursor option (for file list, hex edit...
cursor_new:	ds 1	;a new cursor pos...
highlight_len:	ds 1	;Length of highlight.

VB_task1:	ds 2	;Address for enqueued routine
VB_task2:	ds 2	;Address for enqueued routine
VB_task3:	ds 2	;Address for enqueued routine

resmode:	ds 1	;Resolution: 256, 320(?), 512
evnodd:		ds 1	;Toggle Even/Odd raster mode.

VDC_A_LO:	ds 1	;HSW
VDC_A_HI:	ds 1	;HDS
VDC_B_LO:	ds 1	;HDW
VDC_B_HI:	ds 1	;HDE
VDC_C_LO:	ds 1	;VSW
VDC_C_HI:	ds 1	;VDS
VDC_D:		ds 2	;VDW - A WORD LONG!
VDC_E_LO:	ds 2	;VCR - A BYTE ONLY!

Sprite1Y:	ds 2	;Y-coord for sprite 1
Sprite2Y:	ds 2	;Y-coord for sprite 2
Sprite3X:	ds 2	;X-coord for sprite 3
Sprite4X:	ds 2	;X-coord for sprite 4
Sprite1X:	ds 2	;X-coord for sprite 1
Sprite2X:	ds 2	;X-coord for sprite 2
Sprite3Y:	ds 2	;Y-coord for sprite 3
Sprite4Y:	ds 2	;Y-coord for sprite 4

	;...
		.bss
satb	.ds 512	; the local SATB

;--- CODE area ----------

	.code
	.bank MAIN_BANK
	.org  $C000

	.include "macros_bram.asm"

main:	
	SCREEN_OFF
	jsr	setup_RAM
	jsr	setup_video
;-------
	setvec #VSYNC,vsync_proc
	vec_on #VSYNC
	setvec #HSYNC,hsync_proc
	vec_on #HSYNC
	SCREEN_ON

.main_wait:	
	bbr0	<nmi_passed,.main_wait	;Wait for NMI to pass.
	stz	<nmi_passed
	jsr	TestJoypad	;This changes the values and cursor

.test_vblank_period:
;	lda	$0000		;Get VDC Status Reg.
;	and	#%00000100	;Test if in VBlank
;	beq	.test_vblank_period
	

	bra    .main_wait

	;...

vsync_proc:
	setcolor #256,3,0,0	;Red?
	st0   #6		; restart the scanline counter
	stw   #$40,video_data	; on the first line
	st0   #7
	stw	<x_scroll,video_data
	st0   #8
	stw	<y_scroll,video_data

	inc	<nmi_count
	lda	#$01
	sta	<nmi_passed
	jsr	Cycle_Colours

	rts

hsync_proc:
	setcolor #256,2,2,1	;Yellow?
	rts

;[ USER DATA ]

;==============================================================================
setup_RAM:
	stw	#$0000,<x_scroll
	stw	#$0000,<y_scroll


	stz	<line_number
	stwz	<row_number
	stz	<entry_total
	stz	<entry_number
	stz	<menu_opt
	stz	<cursor_opt
	stz	<nmi_passed
	stwz	<VB_task1
	stwz	<VB_task2
	stwz	<VB_task3
	stz	<menu_status		;Not in anything now...
	stz	<resmode		;Set to 256
	lda	#%00000100
	sta	<evnodd
	
	rts

setup_video:
; blank the background
	jsr	mapsize_128x32
	jsr	clear_VRAM

	map    FontGfx		; map in the memory bank
	vload  FontGfx,#$1000
	set_bgpal #0,FontPal,#3	; fill palette
	set_sprpal #1,SprPal,#1	; fill palette
	map	BGGfx
	vload	BGGfx,#$1000
	map	BG_Map
;	vload	BG_Map,#$0800
	batcpy $0000,#128,BG_Map,#80,#32	;640x256 image.
	setcolor #256,2,2,1	;Yellow?
	jsr	yres_240
	jsr	xres_256

	jsr	Draw_VDC_Text
	jsr	Draw_VDC_Regs
	jsr	Setup_Sprites

	rts




;@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
;@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
;====================================================================
;Routines
	.include "Functions.asm"
	.include "BCD_Routine.asm"
;====================================================================
;Data

VDCA1_Txt: .db "HSW  [xx]-H.Sync.P.W.",0
VDCA2_Txt: .db "HDS  [xx]-H.Dsp.Start",0
VDCB1_Txt: .db "HDW  [xx]-H.Dsp.Width(xxxx)",0
VDCB2_Txt: .db "HDE  [xx]-H.Dsp.End",0
VDCC1_Txt: .db "VSW  [xx]-V.Sync.P.W.",0
VDCC2_Txt: .db "VDS  [xx]-V.Dsp.Start",0
VDCD_Txt:  .db "VDW[xxxx]-V.Dsp.Width(xxxx)",0
VDCE_Txt:  .db "VCR  [xx]-V.Dsp.End",0
Sp1_Txt:   .db "Spr.1 Pos:[xxxx]---[H-Size]",0
Sp2_Txt:   .db "Spr.2 Pos:[xxxx]/   (xxxx)",0
Sp3_Txt:   .db "Spr.3 Pos:[xxxx]---[V-Size]",0
Sp4_Txt:   .db "Spr.4 Pos:[xxxx]/   (xxxx)",0

Bot1_Txt:  .db "U/D:Move Ptr, I/II:Change Num",0
Bot2_Txt:  .db "SEL:Change Horiz. Res",0
Bot3_Txt:  .db "RUN:Toggle '241/242'Line Mode",0
Bot4_Txt:  .db "Position sprites so that tabs",0
Bot5_Txt:  .db "are visible at the edges.",0


FontPal:	.incpal "DimTest1.pcx",0,1
		.incpal "FontPal.pcx",1,2
SprPal:		.incpal "Sprites.pcx",0,1
CursPal:	.incpal "cursorcolours.pcx",0,1
;@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

		.bank	MAIN_BANK+1
		.org	$4000
FontGfx:	.vram	$1000
		.incchr "Font.PCX"

		.bank	MAIN_BANK+2
		.org	$4000
BGGfx:		.vram	$2000
		.incchr "DimTest1.pcx"

		.bank	MAIN_BANK+3
		.org	$4000
BG_Map:		.vram	$0000
		.incbin "dimtest.map"
SprGfx:		.vram	$4000
		.incspr "Sprites.pcx"